<?php if (!defined('ABSPATH')) {exit;}
/**
* Sends feedback about the plugin
*
* @link			https://icopydoc.ru/
* @since		1.7.0
*/ 
// https://skosta.ru/wordpress/woocommerce/
final class IPYTW_Feedback {
	private $pref = 'ipytw';	

	public function __construct($pref = null) {
		if ($pref) {$this->pref = $pref;}

		$this->listen_submits_func();
	}

	public function get_form() { ?>
		<div class="postbox">
			<h2 class="hndle"><?php _e('Send data about the work of the plugin', 'ipytw'); ?></h2>
			<div class="inside">
				<p><?php _e('Sending statistics you help make the plugin even better', 'ipytw'); ?>! <?php _e('The following data will be transferred', 'ipytw'); ?>:</p>
				<ul class="ipytw_ul">
					<li><?php _e('URL your feeds', 'ipytw'); ?></li>
					<li><?php _e('PHP version information ', 'ipytw'); ?></li>
					<li><?php _e('Multisite mode status', 'ipytw'); ?></li>
					<li><?php _e('Technical information and plugin logs', 'ipytw'); ?> Import from YML</li>
				</ul>
				<p><?php _e('Did the plugin help you import products into WooCommerce', 'ipytw'); ?>?</p>
				<form action="<?php echo esc_url($_SERVER['REQUEST_URI']); ?>" method="post" enctype="multipart/form-data">
					<p>
						<input type="radio" name="<?php echo $this->get_radio_name(); ?>" value="yes"><?php _e('Yes', 'ipytw'); ?><br />
						<input type="radio" name="<?php echo $this->get_radio_name(); ?>" value="no"><?php _e('No', 'ipytw'); ?><br />
					</p>
					<p><?php _e("If you don't mind to be contacted in case of problems, please enter your email address", "ipytw"); ?>.</p>
					<p><input type="email" name="<?php echo $this->get_input_name(); ?>"></p>
					<p><?php _e('Your message', 'ipytw'); ?>:</p>
					<p><textarea rows="6" cols="32" name="<?php echo $this->get_textarea_name(); ?>" placeholder="<?php _e('Enter your text to send me a message (You can write me in Russian or English). I check my email several times a day', 'ipytw'); ?>"></textarea></p>
					<?php wp_nonce_field($this->get_nonce_action(), $this->get_nonce_field()); ?>
					<input class="button-primary" type="submit" name="<?php echo $this->get_submit_name(); ?>" value="<?php _e('Send data', 'ipytw'); ?>" />
				</form>	
			</div>
		</div><?php
	}

	public function get_block_support_project() { ?>
		<div class="postbox">
			<h2 class="hndle"><?php _e('Please support the project', 'ipytw'); ?>!</h2>
			<div class="inside">
				<p><?php _e('Thank you for using the plugin', 'ipytw'); ?> <strong>Import from YML</strong></p>
				<p><?php _e('Please help make the plugin better', 'ipytw'); ?> <a href="//forms.gle/6nNnJfffQytsPEVb8" target="_blank" ><?php _e('answering 6 questions', 'ipytw'); ?>!</a></p>
				<p><?php _e('If this plugin useful to you, please support the project one way', 'ipytw'); ?>:</p>
				<ul class="ipytw_ul">
					<li><a href="//wordpress.org/support/plugin/import-from-yml/reviews/" target="_blank"><?php _e('Leave a comment on the plugin page', 'ipytw'); ?></a>.</li>
					<li><?php _e('Support the project financially', 'ipytw'); ?>. <a href="//sobe.ru/na/yml_for_yandex_market" target="_blank"> <?php _e('Donate now', 'ipytw'); ?></a>.</li>
					<li><?php _e('Noticed a bug or have an idea how to improve the quality of the plugin', 'ipytw'); ?>? <a href="mailto:support@icopydoc.ru"><?php _e('Let me know', 'ipytw'); ?></a>.</li>
				</ul>
				<p><?php _e('The author of the plugin Maxim Glazunov', 'ipytw'); ?>.</p>
				<p><span style="color: red;"><?php _e('Accept orders for individual revision of the plugin', 'ipytw'); ?></span>:<br /><a href="mailto:support@icopydoc.ru"><?php _e('Leave a request', 'ipytw'); ?></a>.</p>
			</div>
		</div><?php
	}
	
	private function get_pref() {
		return $this->pref;
	}

	private function get_radio_name() {
		return $this->get_pref().'_its_ok';
	}

	private function get_input_name() {
		return $this->get_pref().'_email';
	}

	private function get_textarea_name() {
		return $this->get_pref().'_message';
	}

	private function get_submit_name() {
		return $this->get_pref().'_submit_send_stat';
	}

	private function get_nonce_action() {
		return $this->get_pref().'_nonce_action_send_stat';
	}

	private function get_nonce_field() {
		return $this->get_pref().'_nonce_field_send_stat';
	}

	private function listen_submits_func() {
		if (isset($_REQUEST[$this->get_submit_name()])) {
			$this->send_data();
			add_action('admin_notices', function() {
				$class = 'notice notice-success is-dismissible';
				$message = __('The data has been sent. Thank you', 'ipytw');
				printf('<div class="%1$s"><p>%2$s</p></div>', $class, $message);
			}, 9999);
		}
	}

	private function send_data() {
		if (!empty($_POST) && check_admin_referer($this->get_nonce_action(), $this->get_nonce_field())) { 	
			/* отправка отчёта */
			if (isset($_REQUEST['ipytw_submit_send_stat'])) {
				if (!empty($_POST) && check_admin_referer('ipytw_nonce_action_send_stat', 'ipytw_nonce_field_send_stat')) { 	
				if (is_multisite()) { 
					$ipytw_is_multisite = 'включен';
					$ipytw_keeplogs = get_blog_option(get_current_blog_id(), 'ipytw_keeplogs');
				} else {
					$ipytw_is_multisite = 'отключен'; 
					$ipytw_keeplogs = get_option('ipytw_keeplogs');
				}

				$unixtime = current_time('Y-m-d H:i');
				$mail_content = '<h1>Заявка (#'.$unixtime.')</h1>';
				$mail_content .= "Версия плагина: ". IPYTW_PLUGIN_VERSION . "<br />";
				$mail_content .= "Версия WP: ".get_bloginfo('version'). "<br />";	 
				$woo_version = get_woo_version_number();
				$mail_content .= "Версия WC: ".$woo_version. "<br />";
				$mail_content .= "Версия PHP: ".phpversion(). "<br />";   
				$mail_content .= "Режим мультисайта: ".$ipytw_is_multisite. "<br />";
				$mail_content .= "Вести логи: ".$ipytw_keeplogs. "<br />";
				$upload_dir = wp_get_upload_dir();
				$mail_content .= 'Расположение логов: <a href="'.$upload_dir['baseurl'].'/import-from-yml/plugin.log" target="_blank">'.$upload_dir['basedir'].'/import-from-yml/plugin.log</a><br />';		
				$possible_problems_arr = IPYTW_Debug_Page::get_possible_problems_list();
				if ($possible_problems_arr[1] > 0) {
					$possible_problems_arr[3] = str_replace('<br/>', PHP_EOL, $possible_problems_arr[3]);
					$mail_content .= "Самодиагностика: <br/>".$possible_problems_arr[3];
				} else {
					$mail_content .= "Самодиагностика: Функции самодиагностики не выявили потенциальных проблем". "<br />";
				}
				if (!class_exists('ImportProductsYMLtoWooCommercePro')) {
					$mail_content .= "Pro: не активна". "<br />";
				} else {
					if (!defined('ipytwp_VER')) {define('ipytwp_VER', 'н/д');} 
					$order_id = ipytw_optionGET('ipytwp_order_id');
					$order_email = ipytw_optionGET('ipytwp_order_email');			
					$mail_content .= "Pro: активна (v ".ipytwp_VER." (#".$order_id." / ".$order_email."))". "<br />";
				}
				if (isset($_REQUEST['ipytw_its_ok'])) {
					$mail_content .= "<br />Помог ли плагин: ".sanitize_text_field($_REQUEST['ipytw_its_ok']);
				}
				if (isset($_POST['ipytw_email'])) {				
					$mail_content .= '<br />Почта: <a href="mailto:'.sanitize_email($_POST['ipytw_email']).'?subject=Ответ разработчика Import from YML (#'.$unixtime.')" target="_blank" rel="nofollow noreferer" title="'.sanitize_email($_POST['ipytw_email']).'">'.sanitize_email($_POST['ipytw_email']).'</a>';
				}
				if (isset($_POST['ipytw_message'])) {
					$mail_content .= "<br />Сообщение: ".sanitize_text_field($_POST['ipytw_message']). "<br />";
				}

				$ipytw_registered_feeds_arr = ipytw_optionGET('ipytw_registered_feeds_arr');
				for ($i = 1; $i < count($ipytw_registered_feeds_arr); $i++) { // с единицы, т.к инфа по конкретным фидам там
					$feed_id = $ipytw_registered_feeds_arr[$i]['id'];

					$ipytw_url_yml_file = ipytw_optionGET('ipytw_url_yml_file', $feed_id, 'set_arr');
					$ipytw_date_sborki = ipytw_optionGET('ipytw_date_sborki', $feed_id, 'set_arr');
					$ipytw_errors = ipytw_optionGET('ipytw_errors', $feed_id, 'set_arr');

					$mail_content .= "<br />ФИД №: ".$feed_id. "<br />";
					$mail_content .= "УРЛ: ".get_site_url(). "<br />";
					$mail_content .= "УРЛ YML-фида: ".$ipytw_url_yml_file . "<br />";
					$mail_content .= "Дата последнего импорта XML: ".$ipytw_date_sborki. "<br />";
					$mail_content .= "Ошибки: ".$ipytw_errors. "<br />";
				}

				add_filter('wp_mail_content_type', array($this, 'set_html_content_type'));
				wp_mail('support@icopydoc.ru', 'Отчёт Import from YML', $mail_content);
				// Сбросим content-type, чтобы избежать возможного конфликта
				remove_filter('wp_mail_content_type', array($this, 'set_html_content_type'));
				}
			} /* end отправка отчёта */ 
		}
	}

	public static function set_html_content_type() {
		return 'text/html';
	}
}
?>